from django import forms
from django.contrib.admin.forms import AdminAuthenticationForm, ERROR_MESSAGE
from django.utils.translation import ugettext as _

class HoneypotLoginForm(AdminAuthenticationForm):
    def clean(self):
        ## Always raise the default error message, because we don't
        ## care what they entered here.
        raise forms.ValidationError(ERROR_MESSAGE)



from django.db import models
from admin_honeypot import listeners

class LoginAttempt(models.Model):
    username = models.CharField(max_length=255, blank=True, null=True)
    password = models.CharField(max_length=255, blank=True, null=True)
    ip_address = models.IPAddressField(blank=True, null=True)
    session_key = models.CharField(max_length=50, blank=True, null=True)
    user_agent = models.TextField(blank=True, null=True)
    timestamp = models.DateTimeField(auto_now_add=True)
    path = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        ordering = ('timestamp',)

    def __unicode__(self):
        return unicode(self.username)



from django.contrib import admin
from admin_honeypot.models import LoginAttempt

class LoginAttemptAdmin(admin.ModelAdmin):
    list_display = ('username', 'get_ip_address', 'get_session_key', 'timestamp', 'get_path')
    list_filter = ('timestamp',)
    readonly_fields = ('username', 'password', 'ip_address', 'session_key', 'user_agent')
    search_fields = ('username', 'password', 'ip_address', 'user_agent', 'path')

    def get_session_key(self, instance):
        return '<a href="?session_key=%(key)s">%(key)s</a>' % {'key': instance.session_key}
    get_session_key.short_description = 'Session'
    get_session_key.allow_tags = True

    def get_ip_address(self, instance):
        return '<a href="?ip_address=%(ip)s">%(ip)s</a>' % {'ip': instance.ip_address}
    get_ip_address.short_description = 'IP Address'
    get_ip_address.allow_tags = True
    
    def get_path(self, instance):
        return '<a href="?path=%(path)s">%(path)s</a>' % {'path': instance.path}
    get_path.short_description = 'URL'
    get_path.allow_tags = True

    def has_add_permission(self, request, obj=None):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

admin.site.register(LoginAttempt, LoginAttemptAdmin)



#!/usr/bin/env python
"""
django-admin-honeypot
=====================

A fake Django admin login screen to notify admins of attempted unauthorized
access. This app was inspired by discussion in and around Paul McMillan's
security talk at DjangoCon 2011.

|travis-ci|_

.. |travis-ci| image:: https://secure.travis-ci.org/dmpayton/django-admin-honeypot.png
.. _travis-ci: http://travis-ci.org/dmpayton/django-admin-honeypot

Basic Usage:

* Add ``admin_honeypot`` to ``settings.INSTALLED_APPS``
* Update urls.py::

    urlpatterns = patterns(''
        ...
        url(r'^admin/', include('admin_honeypot.urls')),
        url(r'^secret/', include(admin.site.urls)),
    )
"""
import os
from admin_honeypot import __version__, __description__, __license__

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup, find_packages

setup(
    name='django-admin-honeypot',
    version=__version__,
    description=__description__,
    long_description=__doc__,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        ],
    keywords='django admin honeypot trap',
    maintainer = 'Derek Payton',
    maintainer_email = 'derek.payton@gmail.com',
    url='https://github.com/dmpayton/django-admin-honeypot',
    download_url='https://github.com/dmpayton/django-admin-honeypot/tarball/v%s' % __version__,
    license=__license__,
    include_package_data=True,
    packages=find_packages(exclude=('tests',)),
    test_suite='tests.setuptest.SetupTestSuite',
    tests_require=(
        'coverage',
        'django',
        'pep8==1.3.1',
      ),
    zip_safe=False,
    )



from admin_honeypot.forms import HoneypotLoginForm
from admin_honeypot.models import LoginAttempt
from admin_honeypot.signals import honeypot
from django.contrib.auth import REDIRECT_FIELD_NAME
from django.contrib.sites.models import Site
from django.shortcuts import render_to_response, redirect
from django.template import RequestContext
from django.utils.translation import ugettext as _

def admin_honeypot(request, extra_context=None):
    if not request.path.endswith('/'):
        return redirect(request.path + '/', permanent=True)
    path = request.get_full_path()

    context = {
        'app_path': path,
        'form': HoneypotLoginForm(request, request.POST or None),
        REDIRECT_FIELD_NAME: path,
        'site': Site.objects.get_current(),
        'title': _('Log in'),
    }
    context['form'].is_valid()
    context.update(extra_context or {})
    if len(path) > 255:
        path = path[:230] +  '...(%d chars)' % len(path)
    if request.method == 'POST':
        failed = LoginAttempt.objects.create(
            username=request.POST.get('username'),
            password=request.POST.get('password'),
            session_key=request.session.session_key,
            ip_address=request.META.get('REMOTE_ADDR'),
            user_agent=request.META.get('HTTP_USER_AGENT'),
            path=path,
        )
        honeypot.send(sender=LoginAttempt, instance=failed, request=request)
    return render_to_response('admin/login.html', context, context_instance=RequestContext(request))



from admin_honeypot.signals import honeypot
from django.conf import settings
from django.contrib.sites.models import get_current_site
from django.core.exceptions import ImproperlyConfigured
from django.core.mail import mail_admins
from django.template.loader import render_to_string

def notify_admins(instance, request, **kwargs):
    context = {
        'request': request,
        'instance': instance,
        'site': get_current_site(request),
    }
    subject = render_to_string('admin_honeypot/email_subject.txt', context).strip()
    message = render_to_string('admin_honeypot/email_message.txt', context).strip()
    mail_admins(subject=subject, message=message)

if getattr(settings, 'ADMIN_HONEYPOT_EMAIL_ADMINS', True):
    honeypot.connect(notify_admins)



__author__ = 'Derek Payton <derek.payton@gmail.com>'
__copyright__ = 'Copyright (c) Derek Payton'
__description__ = 'A fake Django admin login screen to notify admins of attempted unauthorized access.'
__version__ = '0.2.3'
__license__ = 'MIT License'
